@@ -44,6 +44,7 @@ class ConfigService:
         self._select_should_download_descriptions()
         self._select_should_download_links_in_descriptions()
         self._select_should_download_databases()
+        self._select_should_download_forums()
         self._select_should_download_linked_files()
         self._select_should_download_also_with_cookie()
 
@@ -246,6 +247,22 @@ class ConfigService:
 
         self.config_helper.set_property('download_databases', download_databases)
 
+    def _select_should_download_forums(self):
+        """
+        Asks the user if forums should be downloaded
+        """
+        download_forums = self.config_helper.get_download_forums()
+
+        self.section_seperator()
+        Log.info('In forums, students and teachers can discuss and exchange information together.')
+        print('')
+
+        download_forums = cutie.prompt_yes_or_no(
+            Log.special_str('Do you want to download forums of your courses?'), default_is_yes=download_forums
+        )
+
+        self.config_helper.set_property('download_forums', download_forums)
+
     def _select_should_download_descriptions(self):
         """
         Asks the user if descriptions should be downloaded
